==> wiki3_4_0.zip: wiki3_4_0/plugin/todo/ToDoList.pm <==
##############################################################
#
# ToDoꥹȤɽޤ
# ޤŬʥڡToDo򵭽ҤޤToDoεҤϰʲΤ褦ʴǤ
# <pre>
# * 22(ͥ) ȥåȥڡѡ㤦(ư)
# </pre>
# ͥ٤ȹưδ֤϶İʾƤ
# ץ饰λȤϰʲΤ褦ˤʤޤ
# <pre>
# {{todolist ToDo(ToDo򵭽Ҥڡ),5(ɽά)}}
# </pre>
# ͥ٤ι⤤˾夫ɽޤ
# alwaysץĤȥåܥåȴλܥɽ졢
# ToDoλåܥå˥åơִλפ򲡤
# ToDo򵭽ҤڡǤ
# <pre>
# *  22 ȥåȥڡѡ㤦
# </pre>
# Τ褦ѹtodolist鳰ޤ
# ʤalwaysץĤƤʤǤ⡢
# ԤȤƥ󤹤ƱͤΥեबɽޤ
#
##############################################################
package plugin::todo::ToDoList;
#=============================================================
# 󥹥ȥ饯
#=============================================================
sub new{
    my $class = shift;
    my $self = {};
    return bless $self,$class;
}

#=============================================================
# 饤᥽å
#=============================================================
sub inline {
    my $self   = shift;
    my $wiki   = shift;
    my $source = shift;
    my $count  = shift;
    my $option = shift;
    if($count eq "always"){
		$option = "always";
	}
    my $cgi = $wiki->get_CGI;
    my $page = $cgi->param("page");
    my $buf = "";
    my @todolist=();
    
    if($source eq ""){
        return "<font class=\"error\">ڡꤷƤ</font>";
    }
    
    unless($wiki->page_exists($source)){
	return "<font class=\"error\">"
        .Util::escapeHTML($source)."¸ߤޤ</font>";
    }
    
    my $content = $wiki->get_page($source);
    my @lines = split(/\n/,$content);
    
    # 񼰤todo
    foreach(@lines){
        if($_ =~ /^\*\s*(\d+)\s+(.*)/){
            my $priority = $1;
            my $dothing  = $2;
            my $todo = {priority => $priority,dothing => $dothing};
            push(@todolist,$todo);
        }
    }
    
    # ̤ͥǥ
    @todolist = sort {
        return $b->{priority} <=> $a->{priority};
    } @todolist;
    
    # ꥹɽ + λե
    my $login = $wiki->get_login_info();
	if($option eq "always" || defined($login)){
		$buf .= "<div class=\"todo\">"
    	    ."<form action=\"$main::script_name\" method=\"POST\">\n"
			."<input type=\"hidden\" name=\"source\" value=\""
			.Util::escapeHTML($source)."\">\n"
			."<input type=\"hidden\" name=\"page\" value=\""
			.Util::escapeHTML($page)."\">\n"
			."<input type=\"hidden\" name=\"action\" value=\"FINISH_TODO\">";
    }
	$buf .= "<ol>\n";
    my $i=0;
    foreach (@todolist){
        my $priority = $_->{priority};
        my $dothing  = $_->{dothing};
        my $value    = Util::escapeHTML($dothing);
        my $content  = $wiki->process_wiki($dothing);
        $content =~ s/<\/?p>//g;
        $buf .= "<li value=\"$priority\">";
		if($option eq "always" || defined($login)){
            $buf .= "<input name=\"todo.$i\" type=\"checkbox\" value=\"$value\">"
                    .$content."</input></li>\n";
		} else {
			$buf .= $content."</li>\n";
		}
        $i++;
        last if($i==$count);
    }
    
    $buf .= "</ol>";
	if($option eq "always" || defined($login)){
		$buf .= "<input type=\"submit\" value=\"λ\"></form></div>";
    }
	return $buf;
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/todo/ToDoList.pm <==
##############################################################
#
# ToDoꥹȤɽޤ
# ޤŬʥڡToDo򵭽ҤޤToDoεҤϰʲΤ褦ʴǤ
# <pre>
# * 22(ͥ) ȥåȥڡѡ㤦(ư)
# </pre>
# ͥ٤ȹưδ֤϶İʾƤ
# ץ饰λȤϰʲΤ褦ˤʤޤ
# <pre>
# {{todolist ToDo(ToDo򵭽Ҥڡ),5(ɽά)}}
# </pre>
# ͥ٤ι⤤˾夫ɽޤ
# alwaysץĤȥåܥåȴλܥɽ졢
# ToDoλåܥå˥åơִλפ򲡤
# ToDo򵭽ҤڡǤ
# <pre>
# *  22 ȥåȥڡѡ㤦
# </pre>
# Τ褦ѹtodolist鳰ޤ
# ʤalwaysץĤƤʤǤ⡢
# ԤȤƥ󤹤ƱͤΥեबɽޤ
#
##############################################################
package plugin::todo::ToDoList;
use strict;
#=============================================================
# 󥹥ȥ饯
#=============================================================
sub new{
    my $class = shift;
    my $self = {};
    return bless $self,$class;
}

#=============================================================
# 饤᥽å
#=============================================================
sub inline {
    my $self   = shift;
    my $wiki   = shift;
    my $source = shift;
    my $count  = shift;
    my $option = shift;
    if($count eq "always"){
		$option = "always";
	}
    my $cgi = $wiki->get_CGI;
    my $page = $cgi->param("page");
    my $buf = "";
    my @todolist=();
    
    if($source eq ""){
        return "<font class=\"error\">ڡꤷƤ</font>";
    }
    
    unless($wiki->page_exists($source)){
	return "<font class=\"error\">"
        .Util::escapeHTML($source)."¸ߤޤ</font>";
    }
    
    my $content = $wiki->get_page($source);
    my @lines = split(/\n/,$content);
    
    # 񼰤todo
    foreach(@lines){
        if($_ =~ /^\*\s*(\d+)\s+(.*)/){
            my $priority = $1;
            my $dothing  = $2;
            my $todo = {priority => $priority,dothing => $dothing};
            push(@todolist,$todo);
        }
    }
    
    # ̤ͥǥ
    @todolist = sort {
        return $b->{priority} <=> $a->{priority};
    } @todolist;
    
    # ꥹɽ + λե
    my $login = $wiki->get_login_info();
	if($option eq "always" || defined($login)){
		$buf .= "<div class=\"todo\">"
    	    ."<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n"
			."<input type=\"hidden\" name=\"source\" value=\"".Util::escapeHTML($source)."\">\n"
			."<input type=\"hidden\" name=\"page\" value=\"".Util::escapeHTML($page)."\">\n"
			."<input type=\"hidden\" name=\"action\" value=\"FINISH_TODO\">";
    }
	$buf .= "<ol>\n";
    my $i=0;
    foreach (@todolist){
        my $priority = $_->{priority};
        my $dothing  = $_->{dothing};
        my $value    = Util::escapeHTML($dothing);
        my $content  = $wiki->process_wiki($dothing);
        $content =~ s/<\/?p>//g;
        $buf .= "<li value=\"$priority\">";
		if($option eq "always" || defined($login)){
            $buf .= "<input name=\"todo.$i\" type=\"checkbox\" value=\"$value\">"
                    .$content."</input></li>\n";
		} else {
			$buf .= $content."</li>\n";
		}
        $i++;
        last if($i==$count);
    }
    
    $buf .= "</ol>";
	if($option eq "always" || defined($login)){
		$buf .= "<input type=\"submit\" value=\"λ\"></form></div>";
    }
	return $buf;
}

1;
